@@ -739,12 +739,19 @@ proxy_g_signal_cb (GDBusProxy *proxy,
                                 g_warning ("Received unknown action %s", action);
                         }
                 } else {
+                        /* Some clients have assumed it is safe to unref the
+                         * Notification at the end of their NotifyActionCallback
+                         * so we add a temporary ref until we're done with it.
+                         */
+                        g_object_ref (notification);
+
                         notification->priv->activating = TRUE;
                         pair->cb (notification, (char *) action, pair->user_data);
                         notification->priv->activating = FALSE;
-
                         g_free (notification->priv->activation_token);
                         notification->priv->activation_token = NULL;
+
+                        g_object_unref (notification);
                 }
         } else if (g_strcmp0 (signal_name, "ActivationToken") == 0 &&
                    g_variant_is_of_type (parameters, G_VARIANT_TYPE ("(us)"))) {
@@ -819,6 +826,11 @@ notify_notification_show (NotifyNotification *notification,
                 g_variant_builder_add (&hints_builder, "{sv}", key, data);
         }
 
+        if (g_hash_table_lookup (priv->hints, "sender-pid") == NULL) {
+                g_variant_builder_add (&hints_builder, "{sv}", "sender-pid",
+                                       g_variant_new_int64 (getpid ()));
+        }
+
         if (priv->snap_app &&
             g_hash_table_lookup (priv->hints, "desktop-entry") == NULL) {
                 gchar *snap_desktop;
